# Security Policy

## Supported Versions

As long as the project is still WIP, the dev version on test.pypi.org is supported

| Version     | Supported          |
| ----------- | ------------------ |
| 1.0.0-dev   | :white_check_mark: |

## Reporting a Vulnerability

Please send me an [email](mailto:info@loens2.com) if you found any vulnerability.
Describe it as precise as possible and feel free to attach links.
It might take a few days until I respond. Please don't open an Issue unless the problem is related to a bug.
